@@ -3,7 +3,7 @@ import os
 from io import BytesIO
 
 from cameo_claw.cameo_claw_reuse import bytesio_to_gzip, requests_get_write, \
-    bytesio_filename, write_gzip, read_csv_distinct
+    bytesio_filename, write_gzip, pl_read_csv_distinct, pd_read_csv
 from cameo_claw.functional import it_mp_f
 import polars as pl
 import pandas as pd
@@ -26,7 +26,7 @@ def it_download(lst_url, target_directory):
 
 def a_distinct(url, target_directory, lst_distinct_column):
     def write(bytes1):
-        df = read_csv_distinct(bytes1, lst_distinct_column)
+        df = pl_read_csv_distinct(bytes1, lst_distinct_column)
         return bytesio_to_gzip(df, url, target_directory)
 
     return requests_get_write(target_directory, url, write)
@@ -38,7 +38,7 @@ def it_distinct(lst_url, target_directory, lst_distinct_column):
 
 def a_group(url, target_directory, lst_distinct_column, lst_group_by_column):
     def write(bytes1):
-        df = read_csv_distinct(bytes1, lst_distinct_column)
+        df = pl_read_csv_distinct(bytes1, lst_distinct_column)
         g = df.groupby(lst_group_by_column)
         for df in g:
             filename_tail = '_group_' + '-'.join(list(
@@ -60,7 +60,7 @@ def it_group(lst_url, target_directory, lst_distinct_column, lst_group_by_column
 
 def a_filter(url, target_directory, lst_distinct_column, lst_column_match=[], sort_column=''):
     def write(bytes1):
-        df = read_csv_distinct(bytes1, lst_distinct_column)
+        df = pl_read_csv_distinct(bytes1, lst_distinct_column)
         condition = ''
         for lst_col_val in lst_column_match:
             condition += f"""(pl.col('{lst_col_val[0]}')=='{lst_col_val[1]}') | """
@@ -86,7 +86,7 @@ def a_chunk(url, target_directory, lst_distinct_column, lst_column_match=[], sor
         # use polars hang at FastAPI+Python 3.7
         # use polars hang at FastAPI+replit Python 3.8.12
         # use polars OK at FastAPI+Mac Python 3.8.9
-        df = pd.read_csv(BytesIO(bytes1), compression='gzip')
+        df = pd_read_csv(bytes1)
         df = df.drop_duplicates(subset=lst_distinct_column)
 
         # pandas column equals example
