@@ -1,4 +1,5 @@
 import gzip
+import multiprocessing
 from hashlib import md5
 from io import BytesIO
 
@@ -73,5 +74,6 @@ async def streaming_get(md5_hex):
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20432):
+def server(host='0.0.0.0', int_port=20434):
+    multiprocessing.set_start_method('spawn')
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
